@@ -4,7 +4,6 @@ from typing import Any, List, Optional, Tuple, Union
 import numpy as np
 
 import gym
-from gym.logger import deprecation
 from gym.vector.utils.spaces import batch_space
 
 __all__ = ["VectorEnv"]
@@ -28,7 +27,6 @@ class VectorEnv(gym.Env):
         num_envs: int,
         observation_space: gym.Space,
         action_space: gym.Space,
-        new_step_api: bool = False,
     ):
         """Base class for vectorized environments.
 
@@ -36,7 +34,6 @@ class VectorEnv(gym.Env):
             num_envs: Number of environments in the vectorized environment.
             observation_space: Observation space of a single environment.
             action_space: Action space of a single environment.
-            new_step_api (bool): Whether the vector env's step method outputs two boolean arrays (new API) or one boolean array (old API)
         """
         self.num_envs = num_envs
         self.is_vector_env = True
@@ -51,17 +48,9 @@ class VectorEnv(gym.Env):
         self.single_observation_space = observation_space
         self.single_action_space = action_space
 
-        self.new_step_api = new_step_api
-        if not self.new_step_api:
-            deprecation(
-                "Initializing vector env in old step API which returns one bool array instead of two. "
-                "It is recommended to set `new_step_api=True` to use new step API. This will be the default behaviour in future. "
-            )
-
     def reset_async(
         self,
         seed: Optional[Union[int, List[int]]] = None,
-        return_info: bool = False,
         options: Optional[dict] = None,
     ):
         """Reset the sub-environments asynchronously.
@@ -71,7 +60,6 @@ class VectorEnv(gym.Env):
 
         Args:
             seed: The reset seed
-            return_info: If to return info
             options: Reset options
         """
         pass
@@ -79,7 +67,6 @@ class VectorEnv(gym.Env):
     def reset_wait(
         self,
         seed: Optional[Union[int, List[int]]] = None,
-        return_info: bool = False,
         options: Optional[dict] = None,
     ):
         """Retrieves the results of a :meth:`reset_async` call.
@@ -88,7 +75,6 @@ class VectorEnv(gym.Env):
 
         Args:
             seed: The reset seed
-            return_info: If to return info
             options: Reset options
 
         Returns:
@@ -103,21 +89,19 @@ class VectorEnv(gym.Env):
         self,
         *,
         seed: Optional[Union[int, List[int]]] = None,
-        return_info: bool = False,
         options: Optional[dict] = None,
     ):
         """Reset all parallel environments and return a batch of initial observations.
 
         Args:
             seed: The environment reset seeds
-            return_info: If to return the info
             options: If to return the options
 
         Returns:
             A batch of observations from the vectorized environment.
         """
-        self.reset_async(seed=seed, return_info=return_info, options=options)
-        return self.reset_wait(seed=seed, return_info=return_info, options=options)
+        self.reset_async(seed=seed, options=options)
+        return self.reset_wait(seed=seed, options=options)
 
     def step_async(self, actions):
         """Asynchronously performs steps in the sub-environments.
@@ -147,7 +131,7 @@ class VectorEnv(gym.Env):
             actions: element of :attr:`action_space` Batch of actions.
 
         Returns:
-            Batch of (observations, rewards, terminateds, truncateds, infos) or (observations, rewards, dones, infos)
+            Batch of (observations, rewards, terminated, truncated, infos) or (observations, rewards, dones, infos)
         """
         self.step_async(actions)
         return self.step_wait()
@@ -221,21 +205,6 @@ class VectorEnv(gym.Env):
         self.close_extras(**kwargs)
         self.closed = True
 
-    def seed(self, seed=None):
-        """Set the random seed in all parallel environments.
-
-        Args:
-            seed: Random seed for each parallel environment. If ``seed`` is a list of
-                length ``num_envs``, then the items of the list are chosen as random
-                seeds. If ``seed`` is an int, then each parallel environment uses the random
-                seed ``seed + n``, where ``n`` is the index of the parallel environment
-                (between ``0`` and ``num_envs - 1``).
-        """
-        deprecation(
-            "Function `env.seed(seed)` is marked as deprecated and will be removed in the future. "
-            "Please use `env.reset(seed=seed) instead in VectorEnvs."
-        )
-
     def _add_info(self, infos: dict, info: dict, env_num: int) -> dict:
         """Add env info to the info dictionary of the vectorized environment.
 
@@ -340,9 +309,6 @@ class VectorEnvWrapper(VectorEnv):
     def close_extras(self, **kwargs):
         return self.env.close_extras(**kwargs)
 
-    def seed(self, seed=None):
-        return self.env.seed(seed)
-
     def call(self, name, *args, **kwargs):
         return self.env.call(name, *args, **kwargs)
 
